cheesecake.logger.Path

Package cheesecake :: Module logger :: Class Path |
[hide private]
[frames] | no frames]

## Class Path
source code

    object --+
             |
          File --+
                 |
                Path

Instance Methods | [hide private]
| __init__(self, filename, append=False) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
Inherited from `File`: `__call__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, filename, append=False) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: File.__init__